// Define the dimensions of the visualization.
const width = 2000;
const height = 2000;

// Create the SVG canvas.
const svg = d3.select("#network-graph")
  .attr("width", width)
  .attr("height", height);

// Define a color scale for the targets
const color = d3.scaleOrdinal()
  .domain(['Graduate', 'Enrolled', 'Dropout'])
  .range(['green', 'blue', 'red']);

// Load the data.
d3.csv("data.csv")
  .then(function(data) {
  console.log(data, "data loaded correctly");
    // Create the nodes for each student.
    const node = svg.append("g")
      .attr("class", "nodes")
      .selectAll("circle")
      .data(data)
      .enter().append("circle")
      .attr("r", 10)
      .attr("fill", function(d) { return color(d.Target); })
      .on("mouseover", function(d) {
        // Show student info on mouseover.
        console.log(d);
      });

    // Define the force simulation.
    const simulation = d3.forceSimulation(data)
      .force("charge", d3.forceManyBody())
      .force("center", d3.forceCenter(width / 2, height / 2));

    // Update the nodes on each tick of the simulation.
    simulation.on("tick", function() {
      node.attr("cx", function(d) { return d.x; })
          .attr("cy", function(d) { return d.y; });
    });
  })
  .catch(function(error) {
    console.log(error);
  });